# py2zenodo
A Python wrapper for Zenodo REST API

## Installation

We use [Poetry](https://python-poetry.org/) to manage this package.
To install py2zenodo, run the following at the project root directory

```bash
poetry install
```
